======
pyyacp
======


Yet another Python CSV profiler


Description
===========

This library allows to profile CSV files, especially columns.

Some of the available profilers:

* ColumnStatsProfiler (compute typical descriptive statistics and summary statistics about column values)
* ColumPatternProfiler: detect the unicode catgory pattern of a column (e.g. all values consist of 4 digits)
* Data Type Profiling: Very simple data type profiling (e.g. int, float, unicode, date, datetime)
* Data Class Profiling: A more comprehensive description about the data type in combinattion with a descriptive statistic.




Note
====

This project has been set up using PyScaffold 3.0.3. For details and usage
information on PyScaffold see http://pyscaffold.org/.
